@@ -232,6 +232,10 @@ const ApplicationsMenu = new Lang.Class({
         this._button = button;
     },
 
+    isEmpty: function() {
+	return false;
+    },
+
     open: function(animate) {
         this._button.hotCorner.setBarrierSize(0);
         if (this._button.hotCorner.actor) // fallback corner
@@ -548,6 +552,9 @@ const ApplicationsButton = new Lang.Class({
 
         if (category_menu_id) {
             applist = this.applicationsByCategory[category_menu_id];
+            applist.sort(function(a,b) {
+                return a.get_name().toLowerCase() > b.get_name().toLowerCase();
+            });
         } else {
             applist = new Array();
             let favorites = global.settings.get_strv('favorite-apps');
@@ -558,9 +565,6 @@ const ApplicationsButton = new Lang.Class({
             }
         }
 
-        applist.sort(function(a,b) {
-            return a.get_name().toLowerCase() > b.get_name().toLowerCase();
-        });
         return applist;
     },
 
