@@ -24,14 +24,14 @@ function init() {
 }
 
 function enable() {
-  _onActivateOriginal = AppDisplay.AppWellIcon.prototype._onActivate;
-  AppDisplay.AppWellIcon.prototype._onActivate = _onActivate;
+  _onActivateOriginal = AppDisplay.AppIcon.prototype._onActivate;
+  AppDisplay.AppIcon.prototype._onActivate = _onActivate;
 
   _activateResultOriginal = AppDisplay.AppSearchProvider.prototype.activateResult;
   AppDisplay.AppSearchProvider.prototype.activateResult = _activateResult;
 }
 
 function disable() {
-  AppDisplay.AppWellIcon.prototype._onActivate = _onActivateOriginal;
+  AppDisplay.AppIcon.prototype._onActivate = _onActivateOriginal;
   AppDisplay.AppSearchProvider.prototype.activateResult = _activateResultOriginal;
 }
