@@ -726,7 +726,7 @@ const WindowList = new Lang.Class({
                 }
             }));
 
-	let indicatorsBox = new St.BoxLayout();
+	let indicatorsBox = new St.BoxLayout({ x_align: Clutter.ActorAlign.END });
 	box.add(indicatorsBox);
 
         this._workspaceIndicator = new WorkspaceIndicator();
@@ -740,7 +740,7 @@ const WindowList = new Lang.Class({
 
         Main.layoutManager.addChrome(this.actor, { affectsStruts: true,
                                                    trackFullscreen: true });
-        Main.ctrlAltTabManager.addGroup(this.actor, _('Window List'), 'start-here-symbolic');
+        Main.ctrlAltTabManager.addGroup(this.actor, _("Window List"), 'start-here-symbolic');
 
         this._appSystem = Shell.AppSystem.get_default();
         this._appStateChangedId =
